#
# spec file for package python-pyproject-api
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyproject-api
Version:        1.8.0
Release:        1.1
Summary:        API to interact with the python pyproject.toml based projects
License:        MIT
URL:            https://github.com/tox-dev/pyproject-api
Source:         https://files.pythonhosted.org/packages/source/p/pyproject_api/pyproject_api-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatch >= 0.3}
BuildRequires:  %{python_module hatch-vcs >= 0.3}
BuildRequires:  %{python_module hatchling >= 1.18}
BuildRequires:  %{python_module packaging >= 24.1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 75.1}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel >= 0.41.2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-packaging >= 24.1
BuildArch:      noarch
# SECTION testing=
# (except for pytest-cov and -randomly)
BuildRequires:  %{python_module covdefaults >= 2.3}
BuildRequires:  %{python_module pytest >= 8.3.3}
BuildRequires:  %{python_module pytest-cov >= 5}
BuildRequires:  %{python_module pytest-mock >= 3.14}
# /SECTION
%python_subpackages

%description
pyproject-api aims to abstract away interaction with
pyproject.toml style projects in a flexible way.

%prep
%autosetup -p1 -n pyproject_api-%{version}

%build
export LANG=en_US.UTF8
%pyproject_wheel

%install
export LANG=en_US.UTF8
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# gh#tox-dev/pyproject-api#45
skip_tests="test_can_build_on_python_2"
# gh#tox-dev/pyproject-api#77
skip_tests="($skip_tests or test_setuptools_prepare_metadata_for_build_wheel)"
%pytest -k "not $skip_tests"

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/pyproject_api-%{version}*-info
%{python_sitelib}/pyproject_api

%changelog
* Tue Jul  8 2025 Dirk Müller <dmueller@suse.com>
- update to 1.8.0:
  * really drop python<3 support
- update to 1.7.2:
  * Improve the CI
- update to 1.7.1:
  * Move changelog to GH releases
- update to 1.7.0:
  * docs: correct Homepage URL
  * Bump and fix CI for new setuptools
* Thu Nov  9 2023 ecsos <ecsos@opensuse.org>
- Update to 1.6.1:
  - Fix metadata_from_built only extracts one of the dist info files
    in #100
- Update to 1.6.0:
  - Extrat build_<wheel|editable> from
    prepare_metadata_for_build_<wheel|editable> in #99
* Mon Aug 28 2023 Matej Cepl <mcepl@suse.com>
- Update to 1.5.4:
  - Exclude dependabot and pre-commit ci from release notes
  - Bump tools and deps
  - Make sure that the order of Requires-Dist does not matter
- Update to 1.5.3:
  - Bump pypa/gh-action-pypi-publish from 1.8.6 to 1.8.7
  - Fix read_line to raise EOFError if nothing was read
- Update to 1.5.2:
  - Add pyproject-fmt
  - docs: remove (dynamic) years from copyright
  - Drop 2.7 test
  - Add trusted-publish
  - Add 3.12 support
  - Bump pypa/gh-action-pypi-publish from 1.8.5 to 1.8.6
    git ls-files -z -- .github/workflows/check.yml \
    | xargs -0 sed -i 's|3.12.0-alpha.7|3.12.0-beta.1|g'
  - Add ruff
* Fri May  5 2023 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for pyproject-api v. 1.5.1.
